@@ -1,7 +1,7 @@
 /***************************************************************************
- * turtle_boss.cpp  -  turtle enemy class
+ * turtle_boss.cpp  -  turtle boss enemy class
  *
- * Copyright (C) 2003 - 2008 Florian Richter
+ * Copyright (C) 2003 - 2009 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,11 @@
 #include "../../video/gl_surface.h"
 #include "../../core/sprite_manager.h"
 #include "../../core/i18n.h"
+// CEGUI
+#include "CEGUIXMLAttributes.h"
+
+namespace SMC
+{
 
 /* *** *** *** *** *** *** cTurtleBoss *** *** *** *** *** *** *** *** *** *** *** */
 
@@ -36,7 +41,7 @@ cTurtleBoss :: cTurtleBoss( CEGUI::XMLAttributes &attributes )
 : cEnemy()
 {
 	cTurtleBoss::Init();
-	cTurtleBoss::Create_from_Stream( attributes );
+	cTurtleBoss::Create_From_Stream( attributes );
 }
 
 cTurtleBoss :: ~cTurtleBoss( void )
@@ -46,10 +51,10 @@ cTurtleBoss :: ~cTurtleBoss( void )
 
 void cTurtleBoss :: Init( void )
 {
-	type = TYPE_TURTLE_BOSS;
-	posz = 0.092f;
+	m_type = TYPE_TURTLE_BOSS;
+	m_pos_z = 0.092f;
 
-	state = STA_WALK;
+	m_state = STA_WALK;
 	turtle_state = TURTLEBOSS_WALK;	// Walking
 	playercounter = 0;
 
@@ -58,7 +63,7 @@ void cTurtleBoss :: Init( void )
 	Set_Direction( DIR_RIGHT, 1 );
 
 	fire_resistant = 1;
-	ice_resistance = 1;
+	m_ice_resistance = 1;
 	kill_sound = "stomp_4.ogg";
 
 	hits = 0;
@@ -73,8 +78,8 @@ void cTurtleBoss :: Init( void )
 
 cTurtleBoss *cTurtleBoss :: Copy( void )
 {
-	cTurtleBoss *turtle = new cTurtleBoss( startposx, startposy );
-	turtle->Set_Direction( start_direction, 1 );
+	cTurtleBoss *turtle = new cTurtleBoss( m_start_pos_x, m_start_pos_y );
+	turtle->Set_Direction( m_start_direction, 1 );
 	turtle->Set_Color( color_type );
 	turtle->Set_Max_Hits( max_hits );
 	turtle->Set_Max_Downgrade_Counts( max_downgrade_counts );
@@ -83,12 +88,12 @@ cTurtleBoss *cTurtleBoss :: Copy( void )
 	return turtle;
 }
 
-void cTurtleBoss :: Create_from_Stream( CEGUI::XMLAttributes &attributes )
+void cTurtleBoss :: Create_From_Stream( CEGUI::XMLAttributes &attributes )
 {
 	// position
 	Set_Pos( static_cast<float>(attributes.getValueAsInteger( "posx" )), static_cast<float>(attributes.getValueAsInteger( "posy" )), 1 );
 	// direction
-	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( start_direction ) ).c_str() ), 1 );
+	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( m_start_direction ) ).c_str() ), 1 );
 	// color
 	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( color_type ) ).c_str() )) );
 	// max hits
@@ -99,7 +104,7 @@ void cTurtleBoss :: Create_from_Stream( CEGUI::XMLAttributes &attributes )
 	Set_Shell_Time( attributes.getValueAsFloat( "shell_time", shell_time ) );
 }
 
-void cTurtleBoss :: Save_to_Stream( ofstream &file )
+void cTurtleBoss :: Save_To_Stream( ofstream &file )
 {
 	// begin enemy
 	file << "\t<enemy>" << std::endl;
@@ -107,12 +112,12 @@ void cTurtleBoss :: Save_to_Stream( ofstream &file )
 	// name
 	file << "\t\t<Property name=\"type\" value=\"turtleboss\" />" << std::endl;
 	// position
-	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(startposx) << "\" />" << std::endl;
-	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(startposy) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(m_start_pos_x) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(m_start_pos_y) << "\" />" << std::endl;
 	// color
 	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( color_type ) << "\" />" << std::endl;
 	// direction
-	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( start_direction ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( m_start_direction ) << "\" />" << std::endl;
 	// max hit count
 	file << "\t\t<Property name=\"max_hit_count\" value=\"" << max_hits << "\" />" << std::endl;
 	// max downgrade count
@@ -154,7 +159,7 @@ void cTurtleBoss :: Set_Shell_Time( float nmax_downgrade_time )
 	}
 }
 
-void cTurtleBoss :: Set_Direction( ObjectDirection dir, bool new_start_direction /* = 0 */ )
+void cTurtleBoss :: Set_Direction( const ObjectDirection dir, bool new_start_direction /* = 0 */ )
 {
 	if( dir != DIR_RIGHT && dir != DIR_LEFT )
 	{
@@ -164,26 +169,26 @@ void cTurtleBoss :: Set_Direction( ObjectDirection dir, bool new_start_direction
 
 	cEnemy::Set_Direction( dir, new_start_direction );
 
-	if( direction == DIR_RIGHT )
+	if( m_direction == DIR_RIGHT )
 	{
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-			velx = speed_walk;
+			m_velx = speed_walk;
 		}
 		else
 		{
-			velx = speed_shell;
+			m_velx = speed_shell;
 		}
 	}
 	else
 	{
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-			velx = -speed_walk;
+			m_velx = -speed_walk;
 		}
 		else
 		{
-			velx = -speed_shell;
+			m_velx = -speed_shell;
 		}
 	}
 
@@ -197,7 +202,7 @@ void cTurtleBoss :: Set_Direction( ObjectDirection dir, bool new_start_direction
 	// if angry turtle
 	if( turtle_state == TURTLEBOSS_STAND_ANGRY )
 	{
-		velx = 0;
+		m_velx = 0;
 	}
 }
 
@@ -216,19 +221,19 @@ void cTurtleBoss :: Set_Color( DefaultColor col )
 	if( color_type == COL_RED )
 	{
 		// Walk
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_0.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_2.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_0.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_2.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
 		// Walk Turn
 		//images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/turn_1.png" ) );
-		images.push_back( NULL );
+		m_images.push_back( NULL );
 		// Shell
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_front.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_1.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_2.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_3.png" ) );
-		images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_active.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_front.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_1.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_2.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_3.png" ) );
+		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_active.png" ) );
 
 		speed_walk = 3.6f;
 		speed_shell = 14;
@@ -240,7 +245,7 @@ void cTurtleBoss :: Set_Color( DefaultColor col )
 		printf( "Error : Unknown TurtleBoss color : %d\n", color_type );
 	}
 
-	Set_Image( 0, 1 );
+	Set_Image_Num( 0, 1 );
 }
 
 void cTurtleBoss :: Turn_Around( ObjectDirection col_dir /* = DIR_UNDEFINED */ )
@@ -264,61 +269,61 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 		// normal walking
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-		    hits++;
+			hits++;
 
-		    speed_walk += 1.8f;
+			speed_walk += 1.8f;
 
-            if( direction == DIR_RIGHT )
-            {
-                velx = speed_walk;
-            }
-            else
-            {
-                velx = -speed_walk;
-            }
+			if( m_direction == DIR_RIGHT )
+			{
+				m_velx = speed_walk;
+			}
+			else
+			{
+				m_velx = -speed_walk;
+			}
 
 			// state change
-		    if( hits >= max_hits )
-		    {
-                counter = 0;
+			if( hits >= max_hits )
+			{
+				counter = 0;
 
-                hits = 0;
-                downgrade_counts++;
+				hits = 0;
+				downgrade_counts++;
 
 				// die
-                if( downgrade_counts == max_downgrade_counts )
-                {
+				if( downgrade_counts == max_downgrade_counts )
+				{
 					Set_Dead( 1 );
-                }
+				}
 				// downgrade
-                else
-                {
-                    state = STA_STAY;
-                    turtle_state = TURTLEBOSS_STAND_ANGRY;
+				else
+				{
+					m_state = STA_STAY;
+					turtle_state = TURTLEBOSS_STAND_ANGRY;
 
-                    speed_shell += 3;
-                    velx = 0;
-                }
-		    }
+					speed_shell += 3;
+					m_velx = 0;
+				}
+			}
 		}
 		// staying
 		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
 			counter = 0;
-			state = STA_RUN;
+			m_state = STA_RUN;
 			turtle_state = TURTLEBOSS_SHELL_RUN;
-			player_range = 5000;
+			m_player_range = 5000;
 
 			// move into random direction
 			if( rand() % 2 != 1 )
 			{
 				// right
-				velx = speed_shell;
+				m_velx = speed_shell;
 			}
 			else
 			{
 				// left
-				velx = -speed_shell;
+				m_velx = -speed_shell;
 			}
 
 			Update_Direction();
@@ -333,7 +338,7 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-			Move( 0, images[0]->h - images[5]->h, 1 );
+			Move( 0, m_images[0]->m_h - m_images[5]->m_h, 1 );
 		}
 	}
 
@@ -345,12 +350,15 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 		pAudio->Play_Music( "game/courseclear.ogg", 0, 0 );
 
 		// set shell image
-		Set_Image( 5 );
+		Set_Image_Num( 5 );
 
-		massivetype = MASS_PASSIVE;
-		counter = 8;
-		velx = 0;
-		vely = 0;
+		m_massive_type = MASS_PASSIVE;
+		counter = 0;
+		m_velx = 0;
+		m_vely = 0;
+
+		// set scaling for death animation
+		Set_Scale_Affects_Rect( 1 );
 	}
 }
 
@@ -358,11 +366,11 @@ void cTurtleBoss :: DieStep( void )
 {
 	counter += pFramerate->speedfactor * 0.5f;
 
-	if( scalex > 0.1f )
+	if( m_scale_x > 0.1f )
 	{
 		float speed_x = pFramerate->speedfactor * 10;
 
-		if( direction == DIR_LEFT )
+		if( m_direction == DIR_LEFT )
 		{
 			speed_x *= -1;
 		}
@@ -370,25 +378,21 @@ void cTurtleBoss :: DieStep( void )
 		Add_Rotation_Z( speed_x );
 		Add_Scale( -pFramerate->speedfactor * 0.025f );
 
+		// star animation
+		if( counter >= 1 )
+		{
+			Generate_Stars( static_cast<unsigned int>(counter), 0.1f );
+			counter -= static_cast<int>(counter);
+		}
+
 		// finished scale out animation
-		if( scalex <= 0.1f )
+		if( m_scale_x <= 0.1f )
 		{
 			// sound
 			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 
-			// animation
-			cParticle_Emitter *anim = new cParticle_Emitter();
-			anim->Set_Pos( posx, posy );
-			anim->Set_Image( pVideo->Get_Surface( "animation/particles/star.png" ) );
-			anim->Set_Quota( 30 );
-			anim->Set_Pos_Z( posz + 0.000001f );
-			anim->Set_Const_Rotation_Z( -6, 12 );
-			anim->Set_Time_to_Live( 1 );
-			anim->Set_Speed( 1, 4 );
-			anim->Set_Scale( 0.4f, 0.3f );
-			anim->Set_Color( orange, Color( static_cast<Uint8>(6), 60, 20 ) );
-			anim->Set_Blending( BLEND_ADD );
-			pAnimation_Manager->Add( anim );
+			// star explosion animation
+			Generate_Stars( 30 );
 
 			// set empty image
 			cMovingSprite::Set_Image( NULL, 0, 0 );
@@ -400,10 +404,16 @@ void cTurtleBoss :: DieStep( void )
 	else
 	{
 		// wait some time
-		if( counter > 25 )
+		if( counter > 20 )
 		{
+			Set_Active( 0 );
+			turtle_state = TURTLEBOSS_DEAD;
+
 			// next level
 			pPlayer->Goto_Next_Level();
+
+			// reset scaling
+			Set_Scale_Affects_Rect( 0 );
 		}
 	}
 }
@@ -412,7 +422,7 @@ void cTurtleBoss :: Update( void )
 {
 	cEnemy::Update();
 
-	if( !valid_update || !is_Player_range() )
+	if( !m_valid_update || !Is_In_Player_Range() )
 	{
 		return;
 	}
@@ -423,14 +433,14 @@ void cTurtleBoss :: Update( void )
 		walk_count += pFramerate->speedfactor * 0.3f;
 
 		// if not turn around image
-		if( curr_img != 4 )
+		if( m_curr_img != 4 )
 		{
 			if( walk_count >= 4 )
 			{
 				walk_count = 0;
 			}
 
-			Set_Image( static_cast<int>(walk_count) );
+			Set_Image_Num( static_cast<int>(walk_count) );
 		}
 		// turn around image
 		else
@@ -438,19 +448,19 @@ void cTurtleBoss :: Update( void )
 			// force the new image
 			if( walk_count >= 4 )
 			{
-				Set_Image( static_cast<int>(walk_count) );
+				Set_Image_Num( static_cast<int>(walk_count) );
 				Update_Rotation_Hor_velx();
 			}
 			// rotate the turn image
 			else if( walk_count >= 2 )
 			{
-				if( velx < 0 )
+				if( m_velx < 0 )
 				{
-					roty = 180;
+					m_rot_y = 180;
 				}
 				else
 				{
-					roty = 0;
+					m_rot_y = 0;
 				}
 			}
 		}
@@ -463,7 +473,7 @@ void cTurtleBoss :: Update( void )
 		// waiting
 		if( counter < 160 )
 		{
-			Set_Image( 5 ); // front
+			Set_Image_Num( 5 ); // front
 		}
 		else
 		{
@@ -472,46 +482,46 @@ void cTurtleBoss :: Update( void )
 			{
 				if( static_cast<int>(counter) % 5 == 1 )
 				{
-					Set_Image( 9 ); // active
+					Set_Image_Num( 9 ); // active
 				}
 				else
 				{
-					Set_Image( 5 ); // front
+					Set_Image_Num( 5 ); // front
 				}
 			}
 			// activate
 			else
 			{
 				counter = 0;
-                Activate_Turtle();
+				Stand_Up();
 			}
 		}
 
 
-		if( velx != 0 )
+		if( m_velx != 0 )
 		{
-			Add_Velocity( -velx * 0.2f, 0 );
+			Add_Velocity( -m_velx * 0.2f, 0 );
 
-			if( velx < 0.3f && velx > -0.3f )
+			if( m_velx < 0.3f && m_velx > -0.3f )
 			{
-				velx = 0;
+				m_velx = 0;
 			}
 		}
 	}
 	// moving shell
 	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
-        run_time_counter += pFramerate->speedfactor;
+		run_time_counter += pFramerate->speedfactor;
 		// time = seconds since start
-        float time = run_time_counter / speedfactor_fps;
+		float time = run_time_counter / speedfactor_fps;
 
-        if( time > shell_time )
+		if( time > shell_time )
 		{
-		    run_time_counter = 0;
-            Activate_Turtle();
+			run_time_counter = 0;
+			Stand_Up();
 
-            return;
-        }
+			return;
+		}
 
 		walk_count += pFramerate->speedfactor * 0.4f;
 
@@ -522,7 +532,7 @@ void cTurtleBoss :: Update( void )
 			if( playercounter <= 0 )
 			{
 				// do not start collision detection if in maryo
-				if( Col_Box( &pPlayer->col_rect, &col_rect ) )
+				if( pPlayer->m_col_rect.Intersects( m_col_rect ) )
 				{
 					playercounter = 5;
 				}
@@ -538,65 +548,65 @@ void cTurtleBoss :: Update( void )
 			walk_count = 0;
 		}
 
-		Set_Image( 6 + static_cast<int>(walk_count) );
+		Set_Image_Num( 6 + static_cast<int>(walk_count) );
 	}
 	else if( turtle_state == TURTLEBOSS_STAND_ANGRY )
 	{
 		counter += pFramerate->speedfactor;
 
 		// angry
-	    if( static_cast<int>(counter) % 2 == 1 )
-        {
+		if( static_cast<int>(counter) % 2 == 1 )
+		{
 			// slowly fade to the color
 			cMovingSprite::Set_Color( Color( static_cast<Uint8>(255), 250 - static_cast<Uint8>( counter * 1.5f ), 250 - static_cast<Uint8>( counter * 4 ) ) );
-        }
+		}
 		// default
-        else
-        {
+		else
+		{
 			cMovingSprite::Set_Color( white );
-        }
+		}
 
 		// randomize direction
 		if( ( static_cast<int>(counter) / 10 ) % 2 == 1 )
 		{
-			if( direction == DIR_RIGHT )
+			if( m_direction == DIR_RIGHT )
 			{
 				Set_Direction( DIR_LEFT );
 			}
 		}
 		else
 		{
-			if( direction == DIR_LEFT )
+			if( m_direction == DIR_LEFT )
 			{
 				Set_Direction( DIR_RIGHT );
 			}
 		}
 
 		// finished animation
-        if( counter > 60 )
+		if( counter > 60 )
 		{
-		    counter = 0;
+			counter = 0;
 
 			// running shell for some time
-		    turtle_state = TURTLEBOSS_SHELL_RUN;
-		    state = STA_RUN;
+			turtle_state = TURTLEBOSS_SHELL_RUN;
+			m_state = STA_RUN;
 
 			// shell attack sound
 			pAudio->Play_Sound( "enemy/boss/turtle/shell_attack.ogg" );
 
 			// throw more fireballs with downgrades
-		    Throw_Fireballs( 6 + ( downgrade_counts * 2 ) );
+			Throw_Fireballs( 6 + ( downgrade_counts * 2 ) );
 
-            Col_Move( 0, images[0]->col_h - images[5]->col_h, 1, 1 );
-            Set_Image( 5 );
+			Col_Move( 0, m_images[0]->m_col_h - m_images[5]->m_col_h, 1, 1 );
+			Set_Image_Num( 5 );
 
-			if( direction == DIR_RIGHT )
+			if( m_direction == DIR_RIGHT )
 			{
-				velx = speed_shell;
+				m_velx = speed_shell;
 			}
 			else
 			{
-				velx = -speed_shell;
+				m_velx = -speed_shell;
 			}
 		}
 	}
@@ -605,6 +615,73 @@ void cTurtleBoss :: Update( void )
 	Update_Gravity();
 }
 
+void cTurtleBoss :: Stand_Up( void )
+{
+	if( turtle_state != TURTLEBOSS_SHELL_STAND && turtle_state != TURTLEBOSS_SHELL_RUN )
+	{
+		return;
+	}
+
+	// get space needed to stand up
+	float move_y = m_image->m_col_h - m_images[0]->m_col_h;
+
+	cObjectCollisionType *col_list = Collision_Check_Relative( 0, move_y, 0, 0, COLLIDE_ONLY_BLOCKING );
+
+	// failed to stand up because something is blocking
+	if( !col_list->empty() )
+	{
+		delete col_list;
+		return;
+	}
+
+	delete col_list;
+
+	turtle_state = TURTLEBOSS_WALK;
+	m_state = STA_WALK;
+
+	if( m_direction == DIR_RIGHT )
+	{
+		m_velx = speed_walk;
+	}
+	else
+	{
+		m_velx = -speed_walk;
+	}
+
+	Update_Direction();
+	Update_Rotation_Hor_velx();
+
+	pAudio->Play_Sound( "enemy/boss/turtle/power_up.ogg" );
+
+	Col_Move( 0, move_y, 1, 1 );
+
+	// set walking image
+	Set_Image_Num( static_cast<int>(walk_count) );
+}
+
+bool cTurtleBoss :: Hit_Enemy( cEnemy *enemy ) const
+{
+	// invalid
+	if( !enemy )
+	{
+		return 0;
+	}
+
+	// don't collide with already dead enemies
+	if( enemy->dead )
+	{
+		return 0;
+	}
+
+	// hit enemy
+	pAudio->Play_Sound( enemy->kill_sound );
+	pHud_Points->Add_Points( enemy->kill_points, m_pos_x + m_image->m_w / 3, m_pos_y - 5, "", static_cast<Uint8>(255), 1 );
+	enemy->DownGrade( 1 );
+	pPlayer->Add_Kill_Multiplier();
+
+	return 1;
+}
+
 void cTurtleBoss :: Throw_Fireballs( unsigned int amount /* = 6 */ )
 {
 	// start angle
@@ -617,21 +694,38 @@ void cTurtleBoss :: Throw_Fireballs( unsigned int amount /* = 6 */ )
 		// add step size to angle
 		ball_angle += step_size;
 
-		cBall *ball = new cBall( posx + col_rect.w / 2, posy + col_rect.h / 2, this, FIREBALL_EXPLOSION );
+		cBall *ball = new cBall( m_pos_x + m_col_rect.m_w / 2, m_pos_y + m_col_rect.m_h / 2, this, FIREBALL_EXPLOSION );
 		ball->Set_Direction( ball_angle, 15 );
-		ball->Col_Move( ball->velx * 2, ball->vely * 2, 1 );
+		ball->Col_Move( ball->m_velx * 2, ball->m_vely * 2, 1 );
 		pActive_Sprite_Manager->Add( ball );
 	}
 
-	cAnimation_Fireball *anim = new cAnimation_Fireball( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 3 ), 10 );
+	cAnimation_Fireball *anim = new cAnimation_Fireball( m_pos_x + ( m_col_rect.m_w / 2 ), m_pos_y + ( m_col_rect.m_h / 3 ), 10 );
 	anim->Set_Fading_Speed( 0.15f );
-	anim->Set_Pos_Z( posz + 0.000001f );
+	anim->Set_Pos_Z( m_pos_z + 0.000001f );
+	pAnimation_Manager->Add( anim );
+}
+
+void cTurtleBoss :: Generate_Stars( unsigned int amount /* = 1 */, float particle_scale /* = 0.4f */ ) const
+{
+	// animation
+	cParticle_Emitter *anim = new cParticle_Emitter();
+	anim->Set_Pos( m_pos_x + ( m_col_rect.m_w * 0.5f ), m_pos_y + ( m_col_rect.m_h * 0.5f ) );
+	anim->Set_Image( pVideo->Get_Surface( "animation/particles/star.png" ) );
+	anim->Set_Quota( amount );
+	anim->Set_Pos_Z( m_pos_z + 0.000001f );
+	anim->Set_Const_Rotation_Z( -6.0f, 12.0f );
+	anim->Set_Time_to_Live( 1.0f );
+	anim->Set_Speed( 1.0f, 4.0f );
+	anim->Set_Scale( particle_scale, 0.3f );
+	anim->Set_Color( orange, Color( static_cast<Uint8>(6), 60, 20, 0 ) );
+	anim->Set_Blending( BLEND_ADD );
 	pAnimation_Manager->Add( anim );
 }
 
 bool cTurtleBoss :: Is_Update_Valid( void )
 {
-	if( dead || freeze_counter )
+	if( dead || m_freeze_counter )
 	{
 		return 0;
 	}
@@ -639,112 +733,112 @@ bool cTurtleBoss :: Is_Update_Valid( void )
 	return 1;
 }
 
-unsigned int cTurtleBoss :: Validate_Collision( cSprite *obj )
+Col_Valid_Type cTurtleBoss :: Validate_Collision( cSprite *obj )
 {
 	// basic validation checking
-	int basic_valid = Validate_Collision_Ghost( obj );
+	Col_Valid_Type basic_valid = Validate_Collision_Ghost( obj );
 
 	// found valid collision
-	if( basic_valid > -1 )
+	if( basic_valid != COL_VTYPE_NO_GHOST )
 	{
 		return basic_valid;
 	}
 
-	if( obj->massivetype == MASS_MASSIVE )
+	if( obj->m_massive_type == MASS_MASSIVE )
 	{
-		if( obj->type == TYPE_PLAYER )
+		if( obj->m_type == TYPE_PLAYER )
 		{
 			// player is invincible
 			if( pPlayer->invincible )
 			{
-				return 0;
+				return COL_VTYPE_NOT_VALID;
 			}
 			// player counter is active
 			if( turtle_state == TURTLEBOSS_SHELL_RUN && playercounter > 0 )
 			{
-				return 0;
+				return COL_VTYPE_NOT_VALID;
 			}
 		}
-		else if( obj->sprite_array == ARRAY_ENEMY )
+		else if( obj->m_sprite_array == ARRAY_ENEMY )
 		{
-			if( obj->type == TYPE_JPIRANHA )
+			if( obj->m_type == TYPE_FLYON )
 			{
 				// if walking
 				if( turtle_state == TURTLEBOSS_WALK )
 				{
-					return 0;
+					return COL_VTYPE_NOT_VALID;
 				}
 				// shell
 				if( turtle_state == TURTLEBOSS_SHELL_STAND || turtle_state == TURTLEBOSS_SHELL_RUN )
 				{
-					return 1;
+					return COL_VTYPE_INTERNAL;
 				}
 			}
-			if( obj->type == TYPE_ROKKO )
+			if( obj->m_type == TYPE_ROKKO )
 			{
-				return 0;
+				return COL_VTYPE_NOT_VALID;
 			}
-			if( obj->type == TYPE_GEE )
+			if( obj->m_type == TYPE_GEE )
 			{
 				if( turtle_state == TURTLEBOSS_SHELL_STAND || turtle_state == TURTLEBOSS_SHELL_RUN )
 				{
-					return 1;
+					return COL_VTYPE_INTERNAL;
 				}
 
-				return 0;
+				return COL_VTYPE_NOT_VALID;
 			}
-			if( obj->type == TYPE_STATIC_ENEMY )
+			if( obj->m_type == TYPE_STATIC_ENEMY )
 			{
-				return 0;
+				return COL_VTYPE_NOT_VALID;
 			}
 
 			// if moving shell don't collide with enemies
 			if( turtle_state == TURTLEBOSS_SHELL_RUN )
 			{
-				return 1;
+				return COL_VTYPE_INTERNAL;
 			}
 		}
 		// ignore balls
-		else if( obj->type == TYPE_BALL )
+		else if( obj->m_type == TYPE_BALL )
 		{
-		    return 0;
+			return COL_VTYPE_NOT_VALID;
 		}
 
-		return 2;
+		return COL_VTYPE_BLOCKING;
 	}
-	if( obj->type == TYPE_ENEMY_STOPPER )
+	if( obj->m_type == TYPE_ENEMY_STOPPER )
 	{
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-			return 2;
+			return COL_VTYPE_BLOCKING;
 		}
 
-		return 0;
+		return COL_VTYPE_NOT_VALID;
 	}
-	if( obj->massivetype == MASS_HALFMASSIVE )
+	if( obj->m_massive_type == MASS_HALFMASSIVE )
 	{
 		// if moving downwards and the object is on bottom
-		if( vely >= 0 && Is_on_Top( obj ) )
+		if( m_vely >= 0 && Is_On_Top( obj ) )
 		{
-			return 2;
+			return COL_VTYPE_BLOCKING;
 		}
 	}
 
-	return 0;
+	return COL_VTYPE_NOT_VALID;
 }
 
 void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 {
-	if( collision->direction == DIR_UNDEFINED || ( turtle_state == TURTLEBOSS_SHELL_RUN && playercounter > 0 ) || state == STA_OBJ_LINKED )
+	if( collision->direction == DIR_UNDEFINED || ( turtle_state == TURTLEBOSS_SHELL_RUN && playercounter > 0 ) || m_state == STA_OBJ_LINKED )
 	{
 		return;
 	}
 
-	if( collision->direction == DIR_TOP && pPlayer->state != STA_FLY )
+	if( collision->direction == DIR_TOP && pPlayer->m_state != STA_FLY )
 	{
 		if( turtle_state == TURTLEBOSS_WALK )
 		{
-			pointsdisplay->Add_Points( 250, pPlayer->posx, pPlayer->posy );
+			pHud_Points->Add_Points( 250, pPlayer->m_pos_x, pPlayer->m_pos_y );
 
 			if( hits + 1 == max_hits )
 			{
@@ -757,18 +851,18 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
-			pointsdisplay->Add_Points( 100, pPlayer->posx, pPlayer->posy );
+			pHud_Points->Add_Points( 100, pPlayer->m_pos_x, pPlayer->m_pos_y );
 			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_RUN )
 		{
-			pointsdisplay->Add_Points( 50, pPlayer->posx, pPlayer->posy );
+			pHud_Points->Add_Points( 50, pPlayer->m_pos_x, pPlayer->m_pos_y );
 			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 		}
 
 		// animation
 		cParticle_Emitter *anim = new cParticle_Emitter();
-		anim->Set_Pos( posx + ( col_rect.w / 2 ), posy + ( col_rect.h / 2 ) );
+		anim->Set_Pos( m_pos_x + ( m_col_rect.m_w / 2 ), m_pos_y + ( m_col_rect.m_h / 2 ) );
 		Generate_Hit_Animation( anim );
 
 		anim->Set_Speed( 4, 0.8f );
@@ -782,14 +876,14 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 		if( turtle_state == TURTLEBOSS_SHELL_RUN )
 		{
 			// if player is on the left side
-			if( ( pPlayer->col_rect.w / 2 ) + pPlayer->posx < ( col_rect.w / 2 ) + posx )
+			if( ( pPlayer->m_col_rect.m_w / 2 ) + pPlayer->m_pos_x < ( m_col_rect.m_w / 2 ) + m_pos_x )
 			{
-				velx = speed_shell;
+				m_velx = speed_shell;
 			}
 			// on the right side
 			else
 			{
-				velx = -speed_shell;
+				m_velx = -speed_shell;
 			}
 
 			Update_Direction();
@@ -814,38 +908,38 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 			if( collision->direction == DIR_RIGHT )
 			{
 				anim = new cParticle_Emitter();
-				anim->Set_Pos( posx + col_pos.x + col_rect.w, posy + ( col_rect.h / 2 ) );
+				anim->Set_Pos( m_pos_x + m_col_pos.m_x + m_col_rect.m_w, m_pos_y + ( m_col_rect.m_h / 2 ) );
 				anim->Set_Direction_Range( 90, 180 );
-				velx = -speed_shell;
+				m_velx = -speed_shell;
 			}
 			else if( collision->direction == DIR_LEFT )
 			{
 				anim = new cParticle_Emitter();
-				anim->Set_Pos( posx, posy + ( col_rect.h / 2 ) );
+				anim->Set_Pos( m_pos_x, m_pos_y + ( m_col_rect.m_h / 2 ) );
 				anim->Set_Direction_Range( 270, 180 );
-				velx = speed_shell;
+				m_velx = speed_shell;
 			}
 			else
 			{
 				anim = new cParticle_Emitter();
-				anim->Set_Pos( posx + ( col_rect.w / 2 ), posy + col_pos.y + col_rect.h );
+				anim->Set_Pos( m_pos_x + ( m_col_rect.m_w / 2 ), m_pos_y + m_col_pos.m_y + m_col_rect.m_h );
 				anim->Set_Direction_Range( 180, 180 );
 
 				// if player is on the left side
-				if( ( pPlayer->col_rect.w / 2 ) + pPlayer->posx < ( col_rect.w / 2 ) + posx )
+				if( ( pPlayer->m_col_rect.m_w / 2 ) + pPlayer->m_pos_x < ( m_col_rect.m_w / 2 ) + m_pos_x )
 				{
-					velx = speed_shell;
+					m_velx = speed_shell;
 				}
 				// on the right side
 				else
 				{
-					velx = -speed_shell;
+					m_velx = -speed_shell;
 				}
 			}
 
 			anim->Set_Image( pVideo->Get_Surface( "animation/particles/light.png" ) );
 			anim->Set_Quota( 4 );
-			anim->Set_Pos_Z( posz + 0.0001f );
+			anim->Set_Pos_Z( m_pos_z + 0.0001f );
 			anim->Set_Time_to_Live( 0.3f );
 			anim->Set_Speed( 4, 0.5f );
 			anim->Set_Scale( 0.8f );
@@ -860,7 +954,7 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 			// small upwards kick
 			if( collision->direction == DIR_BOTTOM )
 			{
-				vely = -5 + (pPlayer->vely * 0.3f);
+				m_vely = -5 + (pPlayer->m_vely * 0.3f);
 			}
 		}
 		else if( turtle_state == TURTLEBOSS_SHELL_RUN )
@@ -871,7 +965,7 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 				// small upwards kick
 				if( collision->direction == DIR_BOTTOM )
 				{
-					vely = -5 + (pPlayer->vely * 0.3f);
+					m_vely = -5 + (pPlayer->m_vely * 0.3f);
 				}
 			}
 			// other directions downgrade
@@ -891,52 +985,21 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 	if( turtle_state == TURTLEBOSS_SHELL_STAND )
 	{
 		// if able to collide
-		if( vely < -5 )
+		if( m_vely < -5 )
 		{
-			// don't collide with already dead enemies
-			if( enemy->dead )
-			{
-				return;
-			}
-
-			// hit enemy
-			pAudio->Play_Sound( enemy->kill_sound );
-			pointsdisplay->Add_Points( enemy->kill_points, posx + image->w / 3, posy - 5, "", static_cast<Uint8>(255), 1 );
-			enemy->DownGrade( 1 );
-
-			pPlayer->Add_Kill_Multiplier();
+			Hit_Enemy( enemy );
 		}
 	}
 	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
-		// don't collide with already dead enemies
-		if( enemy->dead )
-		{
-			return;
-		}
-
-		// hit enemy
-		pAudio->Play_Sound( enemy->kill_sound );
-		pointsdisplay->Add_Points( enemy->kill_points, posx + image->w / 3, posy - 5, "", static_cast<Uint8>(255), 1 );
-		enemy->DownGrade( 1 );
-
-		pPlayer->Add_Kill_Multiplier();
+		Hit_Enemy( enemy );
 	}
 	else if( turtle_state == TURTLEBOSS_WALK )
 	{
 		// turtle shell
-		if( enemy->type == TYPE_TURTLE && enemy->state == STA_RUN )
+		if( enemy->m_type == TYPE_TURTLE && enemy->m_state == STA_RUN )
 		{
-			// don't collide with already dead enemies
-			if( enemy->dead )
-			{
-				return;
-			}
-
-			// hit enemy
-			pAudio->Play_Sound( enemy->kill_sound );
-			pointsdisplay->Add_Points( enemy->kill_points, posx + image->w / 3, posy - 5, "", static_cast<Uint8>(255), 1 );
-			enemy->DownGrade( 1 );
+			Hit_Enemy( enemy );
 		}
 		else
 		{
@@ -963,20 +1026,20 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 			if( collision->direction == DIR_RIGHT )
 			{
 				anim = new cParticle_Emitter();
-				anim->Set_Pos( col_object->posx + col_object->col_pos.x + 4, posy + ( col_rect.h / 1.35f ) );
+				anim->Set_Pos( col_object->m_pos_x + col_object->m_col_pos.m_x + 4, m_pos_y + ( m_col_rect.m_h / 1.35f ) );
 				anim->Set_Direction_Range( 140, 100 );
 			}
 			else
 			{
 				anim = new cParticle_Emitter();
-				anim->Set_Pos( col_object->posx + col_object->col_pos.x + col_object->col_rect.w - 4, posy + ( col_rect.h / 1.35f ) );
+				anim->Set_Pos( col_object->m_pos_x + col_object->m_col_pos.m_x + col_object->m_col_rect.m_w - 4, m_pos_y + ( m_col_rect.m_h / 1.35f ) );
 				anim->Set_Direction_Range( 320, 100 );
 			}
 
 			anim->Set_Image( pVideo->Get_Surface( "animation/particles/smoke.png" ) );
 			anim->Set_Quota( 5 );
 			anim->Set_Time_to_Live( 0.3f );
-			anim->Set_Pos_Z( col_object->posz - 0.0001f, 0.0002f );
+			anim->Set_Pos_Z( col_object->m_pos_z - 0.0001f, 0.0002f );
 			anim->Set_Speed( 1, 1 );
 			anim->Set_Scale( 0.5f, 0.4f );
 			// add animation
@@ -984,7 +1047,7 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 		}
 
 		// active object collision
-		if( collision->type == CO_ACTIVE )
+		if( collision->m_array == ARRAY_ACTIVE )
 		{
 			Send_Collision( collision );
 		}
@@ -992,15 +1055,15 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 	else if( turtle_state == TURTLEBOSS_SHELL_STAND )
 	{
 		// if able to collide
-		if( vely < -5 )
+		if( m_vely < -5 )
 		{
 			// active object box collision
-			if( collision->type == CO_ACTIVE )
+			if( collision->m_array == ARRAY_ACTIVE )
 			{
 				// get colliding object
 				cSprite *col_object = pActive_Sprite_Manager->Get_Pointer( collision->number );
 
-				if( col_object->type == TYPE_BONUSBOX || col_object->type == TYPE_SPINBOX )
+				if( col_object->m_type == TYPE_BONUSBOX || col_object->m_type == TYPE_SPINBOX )
 				{
 					// get basebox
 					cBaseBox *box = static_cast<cBaseBox *>(col_object);
@@ -1008,7 +1071,7 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 					// if useable
 					if( box->useable_count != 0 )
 					{
-						pointsdisplay->Add_Points( 50, posx + image->w / 3, posy - 5 );
+						pHud_Points->Add_Points( 50, m_pos_x + m_image->m_w / 3, m_pos_y - 5 );
 						Send_Collision( collision );
 						DownGrade( 1 );
 					}
@@ -1019,16 +1082,16 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 	
 	if( collision->direction == DIR_TOP )
 	{
-		if( vely > 0 )
+		if( m_vely > 0 )
 		{
-			vely = 0;
+			m_vely = 0;
 		}
 	}
 	else if( collision->direction == DIR_BOTTOM )
 	{
-		if( vely < 0 )
+		if( m_vely < 0 )
 		{
-			vely = 0;
+			m_vely = 0;
 		}
 	}
 	else
@@ -1039,38 +1102,42 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 
 void cTurtleBoss :: Editor_Activate( void )
 {
+	// get window manager
 	CEGUI::WindowManager &wmgr = CEGUI::WindowManager::getSingleton();
 
 	// direction
 	CEGUI::Combobox *combobox = static_cast<CEGUI::Combobox *>(wmgr.createWindow( "TaharezLook/Combobox", "editor_turtle_boss_direction" ));
-	Editor_Add( UTF8_("Direction"), UTF8_("Direction"), combobox, 100, 75 );
+	Editor_Add( UTF8_("Direction"), UTF8_("Starting direction."), combobox, 100, 75 );
 
 	combobox->addItem( new CEGUI::ListboxTextItem( "left" ) );
 	combobox->addItem( new CEGUI::ListboxTextItem( "right" ) );
 
-	combobox->setText( Get_Direction_Name( start_direction ) );
+	combobox->setText( Get_Direction_Name( m_start_direction ) );
 	combobox->subscribeEvent( CEGUI::Combobox::EventListSelectionAccepted, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Direction_Select, this ) );
 
 	// max hits
 	CEGUI::Editbox *editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_hits" ));
 	Editor_Add( UTF8_("Hits"), UTF8_("Hits until a downgrade"), editbox, 120 );
 
+	editbox->setValidationString( "^[+]?\\d*$" );
 	editbox->setText( int_to_string( max_hits ) );
-	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Hits_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Hits_Text_Changed, this ) );
 
 	// max downgrades
 	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_downgrade_count" ));
 	Editor_Add( UTF8_("Downgrades"), UTF8_("Downgrades until death"), editbox, 120 );
 
+	editbox->setValidationString( "^[+]?\\d*$" );
 	editbox->setText( int_to_string( max_downgrade_counts ) );
-	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Downgrade_Counts_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Downgrade_Counts_Text_Changed, this ) );
 
 	// max shell time
 	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_turtle_boss_max_shell_time" ));
 	Editor_Add( UTF8_("Shell Time"), UTF8_("Time running as shell to rise again"), editbox, 200 );
 
+	editbox->setValidationString( "[+]?[0-9]*\\.?[0-9]*" );
 	editbox->setText( float_to_string( shell_time ) );
-	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Shell_Time_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Shell_Time_Text_Changed, this ) );
 
 	// init
 	Editor_Init();
@@ -1086,65 +1153,42 @@ bool cTurtleBoss :: Editor_Direction_Select( const CEGUI::EventArgs &event )
 	return 1;
 }
 
-bool cTurtleBoss :: Editor_Max_Hits_Key( const CEGUI::EventArgs &event )
+bool cTurtleBoss :: Editor_Max_Hits_Text_Changed( const CEGUI::EventArgs &event )
 {
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
-	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Max_Hits( string_to_int( str_text ) );
 
 	return 1;
 }
 
-bool cTurtleBoss :: Editor_Max_Downgrade_Counts_Key( const CEGUI::EventArgs &event )
+bool cTurtleBoss :: Editor_Max_Downgrade_Counts_Text_Changed( const CEGUI::EventArgs &event )
 {
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
-	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Max_Downgrade_Counts( string_to_int( str_text ) );
 
 	return 1;
 }
 
-bool cTurtleBoss :: Editor_Shell_Time_Key( const CEGUI::EventArgs &event )
+bool cTurtleBoss :: Editor_Shell_Time_Text_Changed( const CEGUI::EventArgs &event )
 {
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
-	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Shell_Time( string_to_float( str_text ) );
 
 	return 1;
 }
 
-void cTurtleBoss :: Activate_Turtle( void )
-{
-	turtle_state = TURTLEBOSS_WALK;
-	state = STA_WALK;
-
-	if( direction == DIR_RIGHT )
-	{
-		velx = speed_walk;
-	}
-	else
-	{
-		velx = -speed_walk;
-	}
-
-	Update_Direction();
-	Update_Rotation_Hor_velx();
-
-	pAudio->Play_Sound( "enemy/boss/turtle/power_up.ogg" );
-
-	if( curr_img != 4 )
-	{
-		Col_Move( 0, images[5]->col_h - images[0]->col_h, 1, 1 );
-	}
-
-	Set_Image( static_cast<int>(walk_count) );
-}
-
 void cTurtleBoss :: Create_Name( void )
 {
-	name = _("Turtle Boss");
-	name += " " + Get_Direction_Name( start_direction );
+	m_name = _("Turtle Boss");
+	m_name += " " + Get_Direction_Name( m_start_direction );
 }
+
+/* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
+
+} // namespace SMC
