@@ -1,7 +1,7 @@
 /***************************************************************************
  * gee.cpp  -  Electro, Lava or Gift monster
  *
- * Copyright (C) 2006 - 2008 Florian Richter
+ * Copyright (C) 2006 - 2009 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -15,12 +15,16 @@
 
 #include "../enemies/gee.h"
 #include "../core/game_core.h"
-#include "../core/camera.h"
 #include "../video/animation.h"
 #include "../player/player.h"
 #include "../gui/hud.h"
 #include "../input/mouse.h"
 #include "../core/i18n.h"
+// CEGUI
+#include "CEGUIXMLAttributes.h"
+
+namespace SMC
+{
 
 /* *** *** *** *** *** *** cGee *** *** *** *** *** *** *** *** *** *** *** */
 
@@ -34,7 +38,7 @@ cGee :: cGee( CEGUI::XMLAttributes &attributes )
 : cEnemy()
 {
 	cGee::Init();
-	cGee::Create_from_Stream( attributes );
+	cGee::Create_From_Stream( attributes );
 }
 
 cGee :: ~cGee( void )
@@ -44,12 +48,12 @@ cGee :: ~cGee( void )
 
 void cGee :: Init( void  )
 {
-	type = TYPE_GEE;
-	player_range = 1000;
-	posz = 0.088f;
-	can_be_on_ground = 0;
+	m_type = TYPE_GEE;
+	m_player_range = 1000;
+	m_pos_z = 0.088f;
+	m_can_be_on_ground = 0;
 
-	state = STA_STAY;
+	m_state = STA_STAY;
 	dest_velx = 0;
 	dest_vely = 0;
 	Set_Max_Distance( 400 );
@@ -72,8 +76,8 @@ void cGee :: Init( void  )
 
 cGee *cGee :: Copy( void )
 {
-	cGee *gee = new cGee( startposx, startposy );
-	gee->Set_Direction( start_direction );
+	cGee *gee = new cGee( m_start_pos_x, m_start_pos_y );
+	gee->Set_Direction( m_start_direction );
 	gee->Set_Max_Distance( max_distance );
 	gee->always_fly = always_fly;
 	gee->wait_time = wait_time;
@@ -83,12 +87,12 @@ cGee *cGee :: Copy( void )
 	return gee;
 }
 
-void cGee :: Create_from_Stream( CEGUI::XMLAttributes &attributes )
+void cGee :: Create_From_Stream( CEGUI::XMLAttributes &attributes )
 {
 	// position
 	Set_Pos( static_cast<float>(attributes.getValueAsInteger( "posx" )), static_cast<float>(attributes.getValueAsInteger( "posy" )), 1 );
 	// direction
-	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( start_direction ) ).c_str() ) );
+	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( m_start_direction ) ).c_str() ) );
 	// max distance
 	Set_Max_Distance( attributes.getValueAsInteger( "max_distance", max_distance ) );
 	// always fly
@@ -101,7 +105,7 @@ void cGee :: Create_from_Stream( CEGUI::XMLAttributes &attributes )
 	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( color_type ) ).c_str() )) );
 }
 
-void cGee :: Save_to_Stream( ofstream &file )
+void cGee :: Save_To_Stream( ofstream &file )
 {
 	// begin enemy
 	file << "\t<enemy>" << std::endl;
@@ -109,10 +113,10 @@ void cGee :: Save_to_Stream( ofstream &file )
 	// name
 	file << "\t\t<Property name=\"type\" value=\"gee\" />" << std::endl;
 	// position
-	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(startposx) << "\" />" << std::endl;
-	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(startposy) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(m_start_pos_x) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(m_start_pos_y) << "\" />" << std::endl;
 	// direction
-	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( start_direction ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( m_start_direction ) << "\" />" << std::endl;
 	// max distance
 	file << "\t\t<Property name=\"max_distance\" value=\"" << static_cast<int>(max_distance) << "\" />" << std::endl;
 	// always fly
@@ -128,51 +132,54 @@ void cGee :: Save_to_Stream( ofstream &file )
 	file << "\t</enemy>" << std::endl;
 }
 
-void cGee :: Load_from_Savegame( cSave_Level_Object *save_object )
+void cGee :: Load_From_Savegame( cSave_Level_Object *save_object )
 {
-	cEnemy::Load_from_Savegame( save_object );
+	cEnemy::Load_From_Savegame( save_object );
 
 	Update_Rotation_Hor_velx();
 }
 
-void cGee :: Set_Direction( ObjectDirection dir )
+void cGee :: Set_Direction( const ObjectDirection dir )
 {
 	// already set
-	if( start_direction == dir )
+	if( m_start_direction == dir )
 	{
 		return;
 	}
 
+	// set direction
+	cEnemy::Set_Direction( dir, 1 );
+	// change left and right to horizontal direction
+	if( m_start_direction == DIR_LEFT || m_start_direction == DIR_RIGHT )
+	{
+		cEnemy::Set_Direction( DIR_HORIZONTAL, 1 );
+	}
+	// change up and down to vertical direction
+	else if( m_start_direction == DIR_UP || m_start_direction == DIR_DOWN )
+	{
+		cEnemy::Set_Direction( DIR_VERTICAL, 1 );
+	}
+
 	// horizontal
-	if( dir == DIR_HORIZONTAL || dir == DIR_LEFT || dir == DIR_RIGHT )
+	if( m_start_direction == DIR_HORIZONTAL )
 	{
-		dir = DIR_HORIZONTAL;
 		dest_vely = 0;
 		dest_velx = 3;
 	}
 	// vertical
 	else
 	{
-		dir = DIR_VERTICAL;
 		dest_vely = 3;
 		dest_velx = 0;
 	}
 
-	cEnemy::Set_Direction( dir, 1 );
-
-	if( velx )
-	{
-		Update_Rotation_Hor_velx( 1 );
-	}
-	else
-	{
-		Update_Rotation_Hor_vely( 1 );
-	}
+	// update direction rotation
+	Update_Rotation_Hor( 1 );
 
 	// stop moving
 	Stop();
 	// set to start position
-	Set_Pos( startposx, startposy );
+	Set_Pos( m_start_pos_x, m_start_pos_y );
 
 	Create_Name();
 }
@@ -200,7 +207,7 @@ void cGee :: Set_Color( DefaultColor col )
 
 	color_type = col;
 
-	string filename_dir;
+	std::string filename_dir;
 
 	// Electro
 	if( color_type == COL_YELLOW )
@@ -246,34 +253,38 @@ void cGee :: Set_Color( DefaultColor col )
 
 	Create_Name();
 
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/1.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/2.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/3.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/4.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/5.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/6.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/7.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/8.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/9.png" ) );
-	images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/10.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/1.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/2.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/3.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/4.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/5.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/6.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/7.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/8.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/9.png" ) );
+	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/10.png" ) );
 
-	Set_Image( 5, 1 );
+	Set_Image_Num( 5, 1 );
+}
+
+void cGee :: Turn_Around( ObjectDirection col_dir /* = DIR_UNDEFINED */ )
+{
+	cEnemy::Turn_Around( col_dir );
+	// update direction rotation
+	Update_Rotation_Hor();
 }
 
 void cGee :: DownGrade( bool force /* = 0 */ )
 {
 	Set_Dead( 1 );
-	massivetype = MASS_PASSIVE;
+	m_massive_type = MASS_PASSIVE;
 	counter = 0;
-	velx = 0;
-	vely = 0;
+	m_velx = 0;
+	m_vely = 0;
 
 	if( !force )
 	{
-		for( unsigned int i = 0; i < 20; i++ )
-		{
-			Generate_Particles();
-		}
+		Generate_Particles( 80 );
 	}
 	else
 	{
@@ -286,9 +297,9 @@ void cGee :: DieStep( void )
 	counter += pFramerate->speedfactor;
 
 	// default death
-	if( rotz != 180 )
+	if( m_rot_z != 180 )
 	{
-		Set_Visible( 0 );
+		Set_Active( 0 );
 	}
 	// falling death
 	else
@@ -299,15 +310,15 @@ void cGee :: DieStep( void )
 			Move( 0, -5 );
 		}
 		// if not below the screen fall
-		else if( posy < game_res_h + col_rect.h )
+		else if( m_pos_y < game_res_h + m_col_rect.m_h )
 		{
 			Move( 0, 20 );
 		}
 		// if below disable
 		else
 		{
-			rotz = 0;
-			Set_Visible( 0 );
+			m_rot_z = 0;
+			Set_Active( 0 );
 		}
 	}
 }
@@ -316,13 +327,13 @@ void cGee :: Update( void )
 {
 	cEnemy::Update();
 
-	if( !valid_update || !is_Player_range() )
+	if( !m_valid_update || !Is_In_Player_Range() )
 	{
 		return;
 	}
 
 	// staying
-	if( state == STA_STAY )
+	if( m_state == STA_STAY )
 	{
 		wait_time_counter += pFramerate->speedfactor;
 
@@ -335,31 +346,31 @@ void cGee :: Update( void )
 	// moving
 	else
 	{
-		Col_Move( velx, vely, 0, 1, 0 );
+		Col_Move( m_velx, m_vely, 0, 1, 0 );
 
 		// update fly distance counter
-		if( velx > 0 )
+		if( m_velx > 0 )
 		{
-			fly_distance_counter += velx * pFramerate->speedfactor;
+			fly_distance_counter += m_velx * pFramerate->speedfactor;
 		}
-		else if( velx < 0 )
+		else if( m_velx < 0 )
 		{
-			fly_distance_counter -= velx * pFramerate->speedfactor;
+			fly_distance_counter -= m_velx * pFramerate->speedfactor;
 		}
-		if( vely > 0 )
+		if( m_vely > 0 )
 		{
-			fly_distance_counter += vely * pFramerate->speedfactor;
+			fly_distance_counter += m_vely * pFramerate->speedfactor;
 		}
-		else if( vely < 0 )
+		else if( m_vely < 0 )
 		{
-			fly_distance_counter -= vely * pFramerate->speedfactor;
+			fly_distance_counter -= m_vely * pFramerate->speedfactor;
 		}
 
 		// check out of map screen
-		if( direction == DIR_DOWN )
+		if( m_direction == DIR_DOWN )
 		{
 			// if below screen move back
-			if( rect.y + col_rect.h > game_res_h )
+			if( m_rect.m_y + m_col_rect.m_h > game_res_h )
 			{
 				Turn_Around( DIR_DOWN );
 			}
@@ -394,12 +405,12 @@ void cGee :: Update( void )
 		walk_count = 0;
 	}
 
-	Set_Image( static_cast<int>(walk_count) );
+	Set_Image_Num( static_cast<int>(walk_count) );
 }
 
-void cGee :: Draw( cSurfaceRequest *request /* = NULL */ )
+void cGee :: Draw( cSurface_Request *request /* = NULL */ )
 {
-	if( !valid_draw )
+	if( !m_valid_draw )
 	{
 		return;
 	}
@@ -407,14 +418,14 @@ void cGee :: Draw( cSurfaceRequest *request /* = NULL */ )
 	// draw distance rect
 	if( editor_level_enabled )
 	{
-		if( start_direction == DIR_HORIZONTAL )
-	    {
-            pVideo->Draw_Rect( startposx - pActive_Camera->x - max_distance, startposy + ( rect.h * 0.5f ) - 5 - pActive_Camera->y, col_rect.w + ( max_distance * 2 ), 10, posz - 0.000001f, &whitealpha128 );
-	    }
-		else if( start_direction == DIR_VERTICAL )
-	    {
-            pVideo->Draw_Rect( startposx + ( rect.w * 0.5f ) - 5 - pActive_Camera->x, startposy - pActive_Camera->y - max_distance, 10, col_rect.h + ( max_distance * 2 ), posz - 0.000001f, &whitealpha128 );
-	    }
+		if( m_start_direction == DIR_HORIZONTAL )
+		{
+			pVideo->Draw_Rect( m_start_pos_x - pActive_Camera->x - max_distance, m_start_pos_y + ( m_rect.m_h * 0.5f ) - 5 - pActive_Camera->y, m_col_rect.m_w + ( max_distance * 2.0f ), 10, m_pos_z - 0.000001f, &whitealpha128 );
+		}
+		else if( m_start_direction == DIR_VERTICAL )
+		{
+			pVideo->Draw_Rect( m_start_pos_x + ( m_rect.m_w * 0.5f ) - 5 - pActive_Camera->x, m_start_pos_y - pActive_Camera->y - max_distance, 10, m_col_rect.m_h + ( max_distance * 2.0f ), m_pos_z - 0.000001f, &whitealpha128 );
+		}
 	}
 
 	cEnemy::Draw( request );
@@ -422,68 +433,65 @@ void cGee :: Draw( cSurfaceRequest *request /* = NULL */ )
 
 void cGee :: Activate( void )
 {
-	// if empty maximum or walk distance
+	// if empty maximum distance or empty walk distance
 	if( !max_distance || !fly_distance )
 	{
 		return;
 	}
 
 	wait_time_counter = 0;
-	state = STA_WALK;
+	m_state = STA_WALK;
 
 	// set velocity
-	velx = dest_velx;
-	vely = dest_vely;
-
+	m_velx = dest_velx;
+	m_vely = dest_vely;
 	// random direction
 	if( rand() % 2 != 1 )
 	{
-		velx *= -1;
+		m_velx *= -1;
 	}
 	if( rand() % 2 != 1 )
 	{
-		vely *= -1;
+		m_vely *= -1;
 	}
 
+	// update rotation
 	Update_Direction();
 
 	// check max distance
 	if( !Check_Max_Distance() )
 	{
+		// turn around also updates the direction rotation
 		Turn_Around();
-
-		if( velx )
-		{
-			Update_Rotation_Hor_velx();
-		}
-		else
-		{
-			Update_Rotation_Hor_vely();
-		}
+	}
+	else
+	{
+		// update direction rotation
+		Update_Rotation_Hor();
 	}
 }
 
 void cGee :: Stop( void )
 {
 	fly_distance_counter = 0;
-	state = STA_STAY;
-	velx = 0;
-	vely = 0;
+	m_state = STA_STAY;
+	m_velx = 0;
+	m_vely = 0;
 }
 
-void cGee :: Generate_Particles( void )
+void cGee :: Generate_Particles( unsigned int amount /* = 4 */ ) const
 {
 	cParticle_Emitter *anim = new cParticle_Emitter();
-	anim->Set_Pos( posx + 15 + ( rand() % static_cast<int>( col_rect.w / 2 ) ), posy + ( ( rand() % static_cast<int>( col_rect.h / 2 ) ) ) );
-	anim->Set_Quota( 4 );
+	anim->Set_Emitter_Rect( m_col_rect.m_x + ( m_col_rect.m_w * 0.3f ), m_col_rect.m_y + ( m_col_rect.m_h * 0.2f ), m_col_rect.m_w * 0.4f, m_col_rect.m_h * 0.3f );
+	anim->Set_Quota( amount );
 	anim->Set_Image( pVideo->Get_Surface( "animation/particles/cloud.png" ) );
 
 	if( !dead )
 	{
-		anim->Set_Speed( 0.3f, 0.2f );
+		anim->Set_Speed( 0, 0.5f );
 
 		// direction
-		if( direction == DIR_LEFT )
+		if( m_direction == DIR_LEFT )
 		{
 			anim->Set_Direction_Range( 90, 180 );
 		}
@@ -518,32 +526,32 @@ void cGee :: Generate_Particles( void )
 	pAnimation_Manager->Add( anim );
 }
 
-bool cGee :: Check_Max_Distance( void )
+bool cGee :: Check_Max_Distance( void ) const
 {
-	if( direction == DIR_UP )
+	if( m_direction == DIR_UP )
 	{
-		if( posy - startposy < -max_distance )
+		if( m_pos_y - m_start_pos_y < -max_distance )
 		{
 			return 0;
 		}
 	}
-	else if( direction == DIR_DOWN )
+	else if( m_direction == DIR_DOWN )
 	{
-		if( posy - startposy > max_distance )
+		if( m_pos_y - m_start_pos_y > max_distance )
 		{
 			return 0;
 		}
 	}
-	else if( direction == DIR_LEFT )
+	else if( m_direction == DIR_LEFT )
 	{
-		if( posx - startposx < -max_distance )
+		if( m_pos_x - m_start_pos_x < -max_distance )
 		{
 			return 0;
 		}
 	}
-	else if( direction == DIR_RIGHT )
+	else if( m_direction == DIR_RIGHT )
 	{
-		if( posx - startposx > max_distance )
+		if( m_pos_x - m_start_pos_x > max_distance )
 		{
 			return 0;
 		}
@@ -554,7 +562,7 @@ bool cGee :: Check_Max_Distance( void )
 
 bool cGee :: Is_Update_Valid( void )
 {
-	if( dead || freeze_counter )
+	if( dead || m_freeze_counter )
 	{
 		return 0;
 	}
@@ -576,23 +584,22 @@ bool cGee :: Is_Draw_Valid( void )
 		}
 	}
 
-
 	return valid;
 }
 
 
-unsigned int cGee :: Validate_Collision( cSprite *obj )
+Col_Valid_Type cGee :: Validate_Collision( cSprite *obj )
 {
-	if( obj->type == TYPE_PLAYER )
+	if( obj->m_type == TYPE_PLAYER )
 	{
-		return 1;
+		return COL_VTYPE_INTERNAL;
 	}
-	if( obj->type == TYPE_BALL )
+	if( obj->m_type == TYPE_BALL )
 	{
-		return 2;
+		return COL_VTYPE_BLOCKING;
 	}
 
-	return 0;
+	return COL_VTYPE_NOT_VALID;
 }
 
 void cGee :: Handle_Collision_Player( cObjectCollision *collision )
@@ -603,14 +610,14 @@ void cGee :: Handle_Collision_Player( cObjectCollision *collision )
 		return;
 	}
 
-	if( collision->direction == DIR_TOP && pPlayer->state != STA_FLY )
+	if( collision->direction == DIR_TOP && pPlayer->m_state != STA_FLY )
 	{
 		pAudio->Play_Sound( kill_sound );
 
 		DownGrade();
 		pPlayer->Action_Jump( 1 );
 
-		pointsdisplay->Add_Points( kill_points, pPlayer->posx, pPlayer->posy, "", static_cast<Uint8>(255), 1 );
+		pHud_Points->Add_Points( kill_points, pPlayer->m_pos_x, pPlayer->m_pos_y, "", static_cast<Uint8>(255), 1 );
 		pPlayer->Add_Kill_Multiplier();
 	}
 	else if( !pPlayer->invincible )
@@ -626,11 +633,11 @@ void cGee :: Handle_Collision_Player( cObjectCollision *collision )
 			}
 			else if( collision->direction == DIR_LEFT )
 			{
-				pPlayer->velx = -7;
+				pPlayer->m_velx = -7;
 			}
 			else if( collision->direction == DIR_RIGHT )
 			{
-				pPlayer->velx = 7;
+				pPlayer->m_velx = 7;
 			}
 		}
 
@@ -646,24 +653,26 @@ void cGee :: Handle_Collision_Massive( cObjectCollision *collision )
 
 void cGee :: Editor_Activate( void )
 {
+	// get window manager
 	CEGUI::WindowManager &wmgr = CEGUI::WindowManager::getSingleton();
 
 	// direction
 	CEGUI::Combobox *combobox = static_cast<CEGUI::Combobox *>(wmgr.createWindow( "TaharezLook/Combobox", "editor_gee_direction" ));
-	Editor_Add( UTF8_("Direction"), UTF8_("Direction"), combobox, 100, 75 );
+	Editor_Add( UTF8_("Direction"), UTF8_("Starting direction."), combobox, 100, 75 );
 
 	combobox->addItem( new CEGUI::ListboxTextItem( "horizontal" ) );
 	combobox->addItem( new CEGUI::ListboxTextItem( "vertical" ) );
 
-	combobox->setText( Get_Direction_Name( start_direction ) );
+	combobox->setText( Get_Direction_Name( m_start_direction ) );
 	combobox->subscribeEvent( CEGUI::Combobox::EventListSelectionAccepted, CEGUI::Event::Subscriber( &cGee::Editor_Direction_Select, this ) );
 
 	// max distance
 	CEGUI::Editbox *editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_gee_max_distance" ));
 	Editor_Add( UTF8_("Distance"), UTF8_("Movable distance"), editbox, 90 );
 
+	editbox->setValidationString( "^[+]?\\d*$" );
 	editbox->setText( int_to_string( max_distance ) );
-	editbox->subscribeEvent( CEGUI::Editbox::EventKeyUp, CEGUI::Event::Subscriber( &cGee::Editor_Max_Distance_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cGee::Editor_Max_Distance_Text_Changed, this ) );
 
 	// always fly
 	combobox = static_cast<CEGUI::Combobox *>(wmgr.createWindow( "TaharezLook/Combobox", "editor_gee_always_fly" ));
@@ -687,15 +696,17 @@ void cGee :: Editor_Activate( void )
 	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_gee_wait_time" ));
 	Editor_Add( UTF8_("Wait time"), UTF8_("Time to wait until moving again after a stop"), editbox, 90 );
 
+	editbox->setValidationString( "[+]?[0-9]*\\.?[0-9]*" );
 	editbox->setText( float_to_string( wait_time ) );
-	editbox->subscribeEvent( CEGUI::Editbox::EventKeyUp, CEGUI::Event::Subscriber( &cGee::Editor_Wait_Time_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cGee::Editor_Wait_Time_Text_Changed, this ) );
 
 	// fly distance
 	editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_gee_fly_distance" ));
 	Editor_Add( UTF8_("Fly distance"), UTF8_("The distance to move each time"), editbox, 90 );
 
+	editbox->setValidationString( "^[+]?\\d*$" );
 	editbox->setText( int_to_string( fly_distance ) );
-	editbox->subscribeEvent( CEGUI::Editbox::EventKeyUp, CEGUI::Event::Subscriber( &cGee::Editor_Fly_Distance_Key, this ) );
+	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cGee::Editor_Fly_Distance_Text_Changed, this ) );
 
 	// init
 	Editor_Init();
@@ -711,10 +722,10 @@ bool cGee :: Editor_Direction_Select( const CEGUI::EventArgs &event )
 	return 1;
 }
 
-bool cGee :: Editor_Max_Distance_Key( const CEGUI::EventArgs &event )
+bool cGee :: Editor_Max_Distance_Text_Changed( const CEGUI::EventArgs &event )
 {
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
-	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	Set_Max_Distance( string_to_int( str_text ) );
 
@@ -738,20 +749,20 @@ bool cGee :: Editor_Always_Fly_Select( const CEGUI::EventArgs &event )
 	return 1;
 }
 
-bool cGee :: Editor_Wait_Time_Key( const CEGUI::EventArgs &event )
+bool cGee :: Editor_Wait_Time_Text_Changed( const CEGUI::EventArgs &event )
 {
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
-	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	wait_time = string_to_float( str_text );
 
 	return 1;
 }
 
-bool cGee :: Editor_Fly_Distance_Key( const CEGUI::EventArgs &event )
+bool cGee :: Editor_Fly_Distance_Text_Changed( const CEGUI::EventArgs &event )
 {
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
-	string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
+	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
 	fly_distance = string_to_int( str_text );
 
@@ -760,27 +771,31 @@ bool cGee :: Editor_Fly_Distance_Key( const CEGUI::EventArgs &event )
 
 void cGee :: Create_Name( void )
 {
-    name = "Gee";
+	m_name = "Gee";
 
-    if( color_type == COL_YELLOW )
-    {
-        name += "lectro";
-    }
-    else if( color_type == COL_RED )
-    {
-        name += "lava";
-    }
-    else if( color_type == COL_GREEN )
-    {
-        name += "venom";
-    }
+	if( color_type == COL_YELLOW )
+	{
+		m_name += "lectro";
+	}
+	else if( color_type == COL_RED )
+	{
+		m_name += "lava";
+	}
+	else if( color_type == COL_GREEN )
+	{
+		m_name += "venom";
+	}
 
-    if( start_direction == DIR_HORIZONTAL )
-    {
-        name += " Hor";
-    }
-    else if( start_direction == DIR_VERTICAL )
-    {
-        name += " Ver";
-    }
+	if( m_start_direction == DIR_HORIZONTAL )
+	{
+		m_name += " Hor";
+	}
+	else if( m_start_direction == DIR_VERTICAL )
+	{
+		m_name += " Ver";
+	}
 }
+
+/* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
+
+} // namespace SMC
