@@ -1,7 +1,7 @@
 /***************************************************************************
  * level_manager.h  -  header for the corresponding cpp file
  *
- * Copyright (C) 2007 - 2008 Florian Richter
+ * Copyright (C) 2007 - 2009 Florian Richter
  ***************************************************************************/
 /*
    This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,9 @@
 #include "../core/camera.h"
 #include "../level/level.h"
 
+namespace SMC
+{
+
 // default files for levels
 #define LEVEL_DEFAULT_MUSIC "land/land_5.ogg"
 #define LEVEL_DEFAULT_BACKGROUND "game/background/green_junglehills.png"
@@ -42,7 +45,7 @@ public:
 	 * delayed : if set the level will be loaded on the next update
 	 * sub_level : if set previous level isn't unloaded
 	*/
-	bool Load( string filename, bool delayed = 0, bool sub_level = 0 );
+	bool Load( std::string filename, bool delayed = 0, bool sub_level = 0 );
 
 	// level camera
 	cCamera *camera;
@@ -55,4 +58,6 @@ extern cLevel_Manager *pLevel_Manager;
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
 
+} // namespace SMC
+
 #endif
